Skip to contents

This function calculates the Area Under the Curve value for the given model. It uses the pROC::auc() function from the pROC package.

Usage

calculate_auc(model, data, .progress = FALSE)

Arguments

model

A model generated by the function mv_model_cox() or mv_model_logreg()

data

Multiple imputed data organized as a long dataset

.progress

TRUE to render the progress bar FALSE otherwise

Value

The same model passed as a parameter with the AUC results stored in results_imp and results_agg

Examples

if (FALSE) { # \dontrun{
calculate_auc(model, data)
} # }