generates an stratified calibration plot
Source:R/get_stratified_calibration_plot_prop.R
get_stratified_calibration_plot_prop.Rdgenerates an stratified calibration plot
Usage
get_stratified_calibration_plot_prop(
data,
n_groups,
type = c("predictions_aggregated", "predictions_recal_type_1",
"predictions_recal_type_2"),
...
)Arguments
- data
dataset where the dependent variable for all the models is
- n_groups
number of points that should be displayed
- type
Type of the predictions that the calibration plot data should be generated from:
"predictions_aggregated","predictions_recal_type_1"or"predictions_recal_type_2". The variable with the predictions need to be generated if it is not consider using thecalculate_predictions_recalibrated_type_1()andcalculate_predictions_recalibrated_type_2()functions.- ...
models that should be plotted in the stratified calibration plot. If they are a named paramter the name is used as strat