An example of the GUSTO-I W region dataset extracted from the book 'Clinical Prediction Models', see references. We have inserted missing values to the dataset in order to be used as an example for this package.
Source:R/gusto.R
gusto.RdAn example of the GUSTO-I W region dataset extracted from the book 'Clinical Prediction Models', see references. We have inserted missing values to the dataset in order to be used as an example for this package.
Usage
data(gusto)Format
A data frame with nine variables:
shoShock: Killip class 3/4 vs. 1/2
a65If the patient is older than 65 years old
diaDiagnosed diabetes
higCategorized for high risk of Anterior Infart Location or Prevous Myocardial Infarction
hypHypotension: Systolic Blood Pressure < 100 mmHg
hrtHeart rate: Pulse>80 (Tachycardia)
ttrTime to relief of chest pain > 1h
day3030 day mortality
sexGender
a dataset with 2188 rows and 9 variables