Function that generates a C-Index forestplot for the given data
Source:R/get_forestplot.R
get_forestplot.RdFunction that generates a C-Index forestplot for the given data
Arguments
- data
Dataset where all the data to plot is stored. It is recommended to be generated using
get_forestplot_data()- center
x intercept to display a stripped vertical line, default
NULL, no center.- digits
decimal digits for the table generation, default
3- ...
extra arguments passed to
ggplot2::theme(). Different subplots are generated in different points of the code some changes could lead to different results than the expected output.