Obtains the \(S_0(t)\) and \(\beta_{overall}\) parameters for recalibration
Source:R/get_recalibrate_params_type_2_cox.R
get_recalibrate_params_type_2_cox.RdCalculates the recalibration type 2 parameters for the recalibrate_data and returns a list with the two needed parameters \(S_0(t)\), the survival estimation in the time \(t\) for the external validation data, and \(\beta_{overall}\), the importance that the \(\beta \cdot X\) values should have over the external validation data.
The survival function estimation is calculated as a Weibull distribution. A Weibull model is derived in the external validation cohort and the value estimated by the model for the time \(t\) is used as the recalibration of \(S_0(t)\). The importance of the \(\beta \cdot X\) is calculated by deriving a Cox model using as only covariate the model \(\beta \cdot X\) values. The derived Cox model coefficient is used as \(\beta_{overall}\).